#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tagged
version:              0.8.10
visibility:           public
id:                   tagged-0.8.10-9VJfLOM9ch68xR35ePL46j
key:                  tagged-0.8.10-9VJfLOM9ch68xR35ePL46j
license:              BSD-3-Clause
copyright:            2009-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/tagged
synopsis:
    Haskell 98 phantom types to avoid unsafely passing dummy arguments

description:
    Haskell 98 phantom types to avoid unsafely passing dummy arguments.

category:             Data, Phantom Types
abi:                  0521b236b4b66ac43bb1f8af54c527db
exposed:              True
exposed-modules:      Data.Proxy.TH Data.Tagged
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tagged-0.8.10
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tagged-0.8.10
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tagged-0.8.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tagged
hs-libraries:         HStagged-0.8.10-9VJfLOM9ch68xR35ePL46j
depends:
    base-4.18.2.1 deepseq-1.4.8.1 template-haskell-2.20.0.0

haddock-interfaces:   /usr/share/doc/haskell-tagged/html/tagged.haddock
haddock-html:         /usr/share/doc/haskell-tagged/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

